pub trait ExtendTarget<T>: ExtendTargetSealed<T> { }๐Deprecated since 0.2.2:
use WidenTarget instead
A type that can be used with turbofish syntax in Extend::extend.
It is unlikely that you will want to use this trait directly. You are probably looking for the
Extend trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".