pub trait TruncateTarget<T>: TruncateTargetSealed<T> { }Expand description
A type that can be used with turbofish syntax in Truncate::truncate.
It is unlikely that you will want to use this trait directly. You are probably looking for the
Truncate trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".