pub trait WidenTarget<T>: WidenTargetSealed<T> { }Expand description
A type that can be used with turbofish syntax in Widen::widen.
It is unlikely that you will want to use this trait directly. You are probably looking for the
Widen trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".