pub trait WidenTarget<T>: WidenTargetSealed<T> { }Expand description
A type that can be used with turbofish syntax in Widen::widen.
It is unlikely that you will want to use this trait directly. You are probably looking for the
Widen trait.
pub trait WidenTarget<T>: WidenTargetSealed<T> { }A type that can be used with turbofish syntax in Widen::widen.
It is unlikely that you will want to use this trait directly. You are probably looking for the
Widen trait.